@@ -2,7 +2,7 @@ from subprocess import check_output, STDOUT
 
 
 def get_version():
-    cmd = "git log -1 --format='%at' | xargs -I{} date -d @{} +'%Y/%m/%d %H:%M:%S'"
+    cmd = 'git log -1 --pretty=format:"%ad" --date=format:"%Y-%m-%d %H:%M:%S"'
     try:
         version = check_output(cmd, stderr=STDOUT, shell=True, universal_newlines=True)
         version = version.replace("\n", "")
